==> teavm-classlib-0.5.1-sources.jar: org/teavm/classlib/java/util/TCheckedListIterator.java <==
/*
 *  Copyright 2014 Alexey Andreev.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.teavm.classlib.java.util;

import org.teavm.classlib.java.lang.TClass;
import org.teavm.classlib.java.lang.TObject;

class TCheckedListIterator<E> implements TListIterator<E> {
    private TListIterator<E> innerIterator;
    private TClass<E> type;

    public TCheckedListIterator(TListIterator<E> innerIterator, TClass<E> type) {
        this.innerIterator = innerIterator;
        this.type = type;
    }

    @Override
    public boolean hasNext() {
        return innerIterator.hasNext();
    }

    @Override
    public E next() {
        return innerIterator.next();
    }

    @Override
    public void remove() {
        innerIterator.remove();
    }

    @Override
    public boolean hasPrevious() {
        return innerIterator.hasPrevious();
    }

    @Override
    public E previous() {
        return innerIterator.previous();
    }

    @Override
    public int nextIndex() {
        return innerIterator.nextIndex();
    }

    @Override
    public int previousIndex() {
        return innerIterator.previousIndex();
    }

    @Override
    public void set(E e) {
        innerIterator.set(type.cast(TObject.wrap(e)));
    }

    @Override
    public void add(E e) {
        innerIterator.add(type.cast(TObject.wrap(e)));
    }
}

==> teavm-classlib-0.11.0-sources.jar: org/teavm/classlib/java/util/TCheckedListIterator.java <==
/*
 *  Copyright 2014 Alexey Andreev.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.teavm.classlib.java.util;

class TCheckedListIterator<E> implements TListIterator<E> {
    private TListIterator<E> innerIterator;
    private Class<E> type;

    TCheckedListIterator(TListIterator<E> innerIterator, Class<E> type) {
        this.innerIterator = innerIterator;
        this.type = type;
    }

    @Override
    public boolean hasNext() {
        return innerIterator.hasNext();
    }

    @Override
    public E next() {
        return innerIterator.next();
    }

    @Override
    public void remove() {
        innerIterator.remove();
    }

    @Override
    public boolean hasPrevious() {
        return innerIterator.hasPrevious();
    }

    @Override
    public E previous() {
        return innerIterator.previous();
    }

    @Override
    public int nextIndex() {
        return innerIterator.nextIndex();
    }

    @Override
    public int previousIndex() {
        return innerIterator.previousIndex();
    }

    @Override
    public void set(E e) {
        innerIterator.set(type.cast(e));
    }

    @Override
    public void add(E e) {
        innerIterator.add(type.cast(e));
    }
}
